from django.db import models


class Navbar(models.Model):

    """Dummy model to create content_type to link with permissions.

    Permissions are added against this models content_type.

    See also: edc_auth.permissions_updater
    """

    id = models.BigAutoField(primary_key=True)

    class Meta:
        verbose_name = "Navbar"
